require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xd7catalog',
  dscmeta_resource_friendly_name: 'XD7Catalog',
  dscmeta_resource_name: 'VE_XD7Catalog',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'XenDesktop7',
  dscmeta_module_version: '2.10.0',
  docs: 'The DSC XD7Catalog resource type.
         Automatically generated from version 2.10.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_name: {
      type: 'String',
      desc: 'Citrix XenDesktop 7 machine catalog name.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_provisioning: {
      type: "Enum['Manual', 'PVS', 'MCS']",
      desc: 'Citrix XenDesktop 7 machine catalog provisioning type.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ismultisession: {
      type: 'Optional[Boolean]',
      desc: 'Citrix XenDesktop 7 machine catalog is multi-session.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'Citrix XenDesktop 7 machine catalog description',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_persistence: {
      type: "Enum['Discard', 'Local', 'PVD']",
      desc: 'Citrix XenDesktop 7 machine catalog persistence type.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_pvsaddress: {
      type: 'Optional[String]',
      desc: 'Citrix XenDesktop 7 machine catalog PVS address',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_minimumfunctionallevel: {
      type: 'Optional[String]',
      desc: 'Citrix XenDesktop 7 machine catalog minimum functional level required for machines to work successfully in the catalog.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Specifies a user account that has permission to install the feature.',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_allocation: {
      type: "Enum['Permanent', 'Random', 'Static']",
      desc: 'Citrix XenDesktop 7 machine catalog allocation type.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_pvsdomain: {
      type: 'Optional[String]',
      desc: 'Citrix XenDesktop 7 machine catalog PVS domain',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
