require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xd7desktopgroup',
  dscmeta_resource_friendly_name: 'XD7DesktopGroup',
  dscmeta_resource_name: 'VE_XD7DesktopGroup',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'XenDesktop7',
  dscmeta_module_version: '2.10.0',
  docs: 'The DSC XD7DesktopGroup resource type.
         Automatically generated from version 2.10.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_colordepth: {
      type: "Optional[Enum['FourBit', 'EightBit', 'SixteenBit', 'TwentyFourBit']]",
      desc: 'Citrix XenDesktop 7 desktop group color depth.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'Citrix XenDesktop 7 desktop group description.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ismultisession: {
      type: 'Boolean',
      desc: 'Citrix XenDesktop 7 desktop group is multi-session.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_displayname: {
      type: 'Optional[String]',
      desc: 'Citrix XenDesktop 7 desktop group display name.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ismaintenancemode: {
      type: 'Optional[Boolean]',
      desc: 'Citrix XenDesktop 7 desktop group is in maintenance mode.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_desktoptype: {
      type: "Enum['Shared', 'Private']",
      desc: 'Citrix XenDesktop 7 desktop group desktop type.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_issecureica: {
      type: 'Optional[Boolean]',
      desc: 'Citrix XenDesktop 7 desktop group uses Secure ICA.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_name: {
      type: 'String',
      desc: 'Citrix XenDesktop 7 desktop group name.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Specifies a user account that has permission to create the delivery group.',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_turnonaddedmachine: {
      type: 'Optional[Boolean]',
      desc: 'Citrix XenDesktop 7 desktop group powers new machines added to the group.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_deliverytype: {
      type: "Enum['AppsOnly', 'DesktopsOnly', 'DesktopsAndApps']",
      desc: 'Citrix XenDesktop 7 desktop group delivery type.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_isremotepc: {
      type: 'Optional[Boolean]',
      desc: 'Citrix XenDesktop 7 desktop group is Remote PC.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_shutdowndesktopsafteruse: {
      type: 'Optional[Boolean]',
      desc: 'Citrix XenDesktop 7 desktop group shuts down desktops after use.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enabled: {
      type: 'Optional[Boolean]',
      desc: 'Citrix XenDesktop 7 desktop group is enabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
