require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xd7entitlementpolicy',
  dscmeta_resource_friendly_name: 'XD7EntitlementPolicy',
  dscmeta_resource_name: 'VE_XD7EntitlementPolicy',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'XenDesktop7',
  dscmeta_module_version: '2.10.0',
  docs: 'The DSC XD7EntitlementPolicy resource type.
         Automatically generated from version 2.10.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_enabled: {
      type: 'Optional[Boolean]',
      desc: 'Citrix XenDesktop 7 entitlement policy is enabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'Citrix XenDesktop 7 entitlement policy description.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_includeusers: {
      type: 'Optional[Array[String]]',
      desc: 'Citrix XenDesktop 7 entitlement policy included users.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'Optional[String]',
      desc: 'Citrix XenDesktop 7 entitlement policy name.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Specifies the user account to run the resource under.',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_excludeusers: {
      type: 'Optional[Array[String]]',
      desc: 'Citrix XenDesktop 7 entitlement policy excluded users.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_entitlementtype: {
      type: "Enum['Desktop', 'Application']",
      desc: 'Citrix XenDesktop 7 entitlement policy type.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_deliverygroup: {
      type: 'String',
      desc: 'Citrix XenDesktop 7 delivery group name.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
