require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xd7storefrontexplicitcommonoptions',
  dscmeta_resource_friendly_name: 'XD7StoreFrontExplicitCommonOptions',
  dscmeta_resource_name: 'VE_XD7StoreFrontExplicitCommonOptions',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'XenDesktop7',
  dscmeta_module_version: '2.10.0',
  docs: 'The DSC XD7StoreFrontExplicitCommonOptions resource type.
         Automatically generated from version 2.10.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_showpasswordexpirywarning: {
      type: "Optional[Enum['Custom', 'Never', 'Windows']]",
      desc: 'Show the password expiry warning to the user',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_defaultdomain: {
      type: 'Optional[String]',
      desc: 'The default domain to use when omitted during login',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowzerolengthpassword: {
      type: 'Optional[Boolean]',
      desc: 'Allow a zero length password',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_domains: {
      type: 'Optional[Array[String]]',
      desc: 'List of trusted domains',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_passwordexpirywarningperiod: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'The period of time in days before the expiry warning should be shown',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_allowuserpasswordchange: {
      type: "Optional[Enum['Always', 'ExpiredOnly', 'Never']]",
      desc: 'Configure when a user can change a password',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_hidedomainfield: {
      type: 'Optional[Boolean]',
      desc: 'Hide the domain field on the login form',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_storename: {
      type: 'String',
      desc: 'StoreFront store name',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
