require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xd7storefrontfarmconfiguration',
  dscmeta_resource_friendly_name: 'XD7StoreFrontFarmConfiguration',
  dscmeta_resource_name: 'VE_XD7StoreFrontFarmConfiguration',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'XenDesktop7',
  dscmeta_module_version: '2.10.0',
  docs: 'The DSC XD7StoreFrontFarmConfiguration resource type.
         Automatically generated from version 2.10.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_leasingstatusexpiryfailed: {
      type: 'Optional[String]',
      desc: 'Period of time before retrying a XenDesktop 7 and greater farm in failed leasing mode in seconds',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_connectiontimeout: {
      type: 'Optional[String]',
      desc: 'Connection timeout when connecting to the Xml service in seconds',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_storename: {
      type: 'String',
      desc: 'StoreFront store name',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_leasingstatusexpirypending: {
      type: 'Optional[String]',
      desc: 'Period of time before retrying a XenDesktop 7 and greater farm pending leasing mode in seconds',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enablefiletypeassociation: {
      type: 'Optional[Boolean]',
      desc: 'Enable file type association',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_backgroundhealthcheckpollingperiod: {
      type: 'Optional[String]',
      desc: 'Period of time between polling XenApp or XenDesktop server health in seconds',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_communicationtimeout: {
      type: 'Optional[String]',
      desc: 'Communication timeout when using to the Xml service in seconds',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_pooledsockets: {
      type: 'Optional[Boolean]',
      desc: 'Use pooled sockets',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_advancedhealthcheck: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether an advanced health-check should be performed',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_leasingstatusexpiryleasing: {
      type: 'Optional[String]',
      desc: 'Period of time before retrying a XenDesktop 7 and greater farm in leasing mode in seconds',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_servercommunicationattempts: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Number of server connection attempts before failing',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
  },
)
