require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xd7storefrontoptimalgateway',
  dscmeta_resource_friendly_name: 'XD7StoreFrontOptimalGateway',
  dscmeta_resource_name: 'VE_XD7StoreFrontOptimalGateway',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'XenDesktop7',
  dscmeta_module_version: '2.10.0',
  docs: 'The DSC XD7StoreFrontOptimalGateway resource type.
         Automatically generated from version 2.10.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_gatewayname: {
      type: 'String',
      desc: 'StoreFront gateway name',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_farms: {
      type: 'Optional[Array[String]]',
      desc: 'Farms',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_stasbypassduration: {
      type: 'Optional[String]',
      desc: 'Time before retrying a failed STA server',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_staurls: {
      type: 'Array[String]',
      desc: 'Secure Ticket Authority server Urls',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_usetwotickets: {
      type: 'Optional[Boolean]',
      desc: 'Request STA tickets from two STA servers',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_resourcesvirtualpath: {
      type: 'String',
      desc: 'Resources Virtual Path',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_zones: {
      type: 'Optional[Array[String]]',
      desc: 'Zones',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Ensure',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_siteid: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'Site Id',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_hostnames: {
      type: 'Array[String]',
      desc: 'Hostnames',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_enabledondirectaccess: {
      type: 'Optional[Boolean]',
      desc: 'Enabled On Direct Access',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_stasuseloadbalancing: {
      type: 'Optional[Boolean]',
      desc: 'Load balance between the configured STA servers',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enablesessionreliability: {
      type: 'Optional[Boolean]',
      desc: 'Enable session reliability',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
