require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xd7storefrontroaminggateway',
  dscmeta_resource_friendly_name: 'XD7StoreFrontRoamingGateway',
  dscmeta_resource_name: 'VE_XD7StoreFrontRoamingGateway',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'XenDesktop7',
  dscmeta_module_version: '2.10.0',
  docs: 'The DSC XD7StoreFrontRoamingGateway resource type.
         Automatically generated from version 2.10.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_subnetipaddress: {
      type: 'Optional[String]',
      desc: 'IP address',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_gatewayurl: {
      type: 'String',
      desc: 'The Gateway Url',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_stasbypassduration: {
      type: 'Optional[String]',
      desc: 'Time before retrying a failed STA server',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_secureticketauthorityurls: {
      type: 'Optional[Array[String]]',
      desc: 'Secure Ticket Authority server Urls',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_smartcardfallbacklogontype: {
      type: 'Optional[String]',
      desc: 'The login type to use when SmartCard fails',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_name: {
      type: 'String',
      desc: 'Gateway friendly name',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_callbackurl: {
      type: 'Optional[String]',
      desc: 'The Gateway authentication call-back Url',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Ensure',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_gslburl: {
      type: 'Optional[String]',
      desc: ' GSLB domain used by multiple gateways',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sessionreliability: {
      type: 'Optional[Boolean]',
      desc: 'Enable session reliability',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_requesttickettwostas: {
      type: 'Optional[Boolean]',
      desc: 'Request STA tickets from two STA servers',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_logontype: {
      type: "Enum['UsedForHDXOnly', 'Domain', 'RSA', 'DomainAndRSA', 'SMS', 'GatewayKnows', 'SmartCard', 'None']",
      desc: 'The login type required and supported by the Gateway',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_stasuseloadbalancing: {
      type: 'Optional[Boolean]',
      desc: 'Load balance between the configured STA servers',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_version: {
      type: 'Optional[String]',
      desc: 'The Citrix NetScaler Gateway version',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
