require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xd7storefrontstore',
  dscmeta_resource_friendly_name: 'XD7StoreFrontStore',
  dscmeta_resource_name: 'VE_XD7StoreFrontStore',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'XenDesktop7',
  dscmeta_module_version: '2.10.0',
  docs: 'The DSC XD7StoreFrontStore resource type.
         Automatically generated from version 2.10.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_authvirtualpath: {
      type: 'Optional[String]',
      desc: 'Citrix StoreFront authenication service virtual path',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowsessionreconnect: {
      type: 'Optional[Boolean]',
      desc: 'Allow sessions to be reconnected',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_lockeddown: {
      type: 'Optional[Boolean]',
      desc: 'All the resources delivered by locked-down Store are auto subscribed and do not allow for un-subscription',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Ensure',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_siteid: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'Citrix StoreFront site id',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_substitutedesktopimage: {
      type: 'Optional[Boolean]',
      desc: 'Substitute the desktop image provided by XenApp or XenDesktop with the StoreFront default',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_storevirtualpath: {
      type: 'Optional[String]',
      desc: 'Citrix StoreFront store virtual path',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_authtype: {
      type: "Enum['Explicit', 'Anonymous']",
      desc: 'Citrix StoreFront Authentication type',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_storename: {
      type: 'String',
      desc: 'Citrix StoreFront name',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
