require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xd7storefrontstorefarm',
  dscmeta_resource_friendly_name: 'XD7StoreFrontStoreFarm',
  dscmeta_resource_name: 'VE_XD7StoreFrontStoreFarm',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'XenDesktop7',
  dscmeta_module_version: '2.10.0',
  docs: 'The DSC XD7StoreFrontStoreFarm resource type.
         Automatically generated from version 2.10.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_transporttype: {
      type: "Optional[Enum['HTTP', 'HTTPS', 'SSL']]",
      desc: 'Type of transport to use. Http, Https, SSL for example',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_serviceurls: {
      type: 'Optional[Array[String]]',
      desc: 'The url to the service location used to provide web and SaaS apps via this farm',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_restrictpops: {
      type: 'Optional[String]',
      desc: 'Cloud deployments only otherwise ignored. Restricts GWaaS traffic to the specified POP',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sslrelayport: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'The SSL Relay port',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_allfailedbypassduration: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Period of time to skip all xml service requests should all servers fail to respond',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_servers: {
      type: 'Optional[Array[String]]',
      desc: 'The hostnames or IP addresses of the xml services',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_farmtype: {
      type: "Optional[Enum['XenApp', 'XenDesktop', 'AppController', 'VDIinaBox', 'Store']]",
      desc: 'The type of farm',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_farmname: {
      type: 'String',
      desc: 'The name of the Farm',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_zones: {
      type: 'Optional[Array[String]]',
      desc: 'The list of Zone names associated with the Store Farm',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_radetickettimetolive: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Period of time a RADE launch ticket is valid once requested on pre 7.0 XenApp and XenDesktop farms',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Ensure',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_farmguid: {
      type: 'Optional[String]',
      desc: 'Cloud deployments only otherwise ignored. A tag indicating the scope of the farm',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_storename: {
      type: 'String',
      desc: 'StoreFront store name',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_bypassduration: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Period of time to skip a server when is fails to respond',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_product: {
      type: 'Optional[String]',
      desc: 'Cloud deployments only otherwise ignored. The product name of the farm configured',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_loadbalance: {
      type: 'Optional[Boolean]',
      desc: 'Round robin load balance the xml service servers',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maxfailedserversperrequest: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum number of servers within a single farm that can fail before aborting a request',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_port: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Service communication port',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_tickettimetolive: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Period of time an ICA launch ticket is valid once requested on pre 7.0 XenApp and XenDesktop farms',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
  },
)
