require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xd7storefrontwebreceivercommunication',
  dscmeta_resource_friendly_name: 'XD7StoreFrontWebReceiverCommunication',
  dscmeta_resource_name: 'VE_XD7StoreFrontWebReceiverCommunication',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'XenDesktop7',
  dscmeta_module_version: '2.10.0',
  docs: 'The DSC XD7StoreFrontWebReceiverCommunication resource type.
         Automatically generated from version 2.10.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_loopbackportusinghttp: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'When loopback is set to OnUsingHttp, the port number to use for loopback communications',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_loopback: {
      type: "Optional[Enum['On', 'Off', 'OnUsingHttp']]",
      desc: 'Whether to use the loopback address for communications with the store service, rather than the actual StoreFront server URL',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_proxyenabled: {
      type: 'Optional[Boolean]',
      desc: 'Is the communications proxy enabled',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_proxyprocessname: {
      type: 'Optional[String]',
      desc: 'The name of the process acting as proxy',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_timeout: {
      type: 'Optional[String]',
      desc: 'Timeout value for communicating with StoreFront',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_attempts: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'How many attempts WebReceiver should make to contact StoreFront before it gives up',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_proxyport: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'The port to use for the communications proxy',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_storename: {
      type: 'String',
      desc: 'StoreFront store name',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
