require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xd7storefrontwebreceiveruserinterface',
  dscmeta_resource_friendly_name: 'XD7StoreFrontWebReceiverUserInterface',
  dscmeta_resource_name: 'VE_XD7StoreFrontWebReceiverUserInterface',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'XenDesktop7',
  dscmeta_module_version: '2.10.0',
  docs: 'The DSC XD7StoreFrontWebReceiverUserInterface resource type.
         Automatically generated from version 2.10.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_enableappsfolderview: {
      type: 'Optional[Boolean]',
      desc: 'Allows the user to turn off folder view when in a locked-down store or unauthenticated store',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_appshortcutsallowsessionreconnect: {
      type: 'Optional[Boolean]',
      desc: 'Enable App Shortcuts to support session reconnect',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_defaultview: {
      type: "Optional[Enum['Apps', 'Auto', 'Desktops']]",
      desc: 'The view to show after logon',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_autolaunchdesktop: {
      type: 'Optional[Boolean]',
      desc: 'Whether to auto-launch desktop at login if there is only one desktop available for the user',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_workspacecontrolshowreconnectbutton: {
      type: 'Optional[Boolean]',
      desc: 'Whether to show the reconnect button or link',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_showdesktopsview: {
      type: 'Optional[Boolean]',
      desc: 'Whether to show the desktops tab',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_workspacecontrolshowdisconnectbutton: {
      type: 'Optional[Boolean]',
      desc: 'Whether to show the disconnect button or link',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_receiverconfigurationenabled: {
      type: 'Optional[Boolean]',
      desc: 'Enable the Receiver Configuration .CR download file',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_workspacecontrollogoffaction: {
      type: "Optional[Enum['Disconnect', 'None', 'Terminate']]",
      desc: 'Whether to disconnect or terminate HDX sessions when actively logging off Receiver for Web',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_appshortcutsenabled: {
      type: 'Optional[Boolean]',
      desc: 'Enable App Shortcuts',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_showappsview: {
      type: 'Optional[Boolean]',
      desc: 'Whether to show the apps view tab',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_workspacecontrolautoreconnectatlogon: {
      type: 'Optional[Boolean]',
      desc: 'Whether to perform auto-reconnect at login',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_storename: {
      type: 'String',
      desc: 'StoreFront store name',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_multiclicktimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'The time period for which the spinner control is displayed, after the user clicks on the App or Desktop icon within Receiver for Web',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_workspacecontrolenabled: {
      type: 'Optional[Boolean]',
      desc: 'Whether to enable workspace control',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
