require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xd7waitforsite',
  dscmeta_resource_friendly_name: 'XD7WaitForSite',
  dscmeta_resource_name: 'VE_XD7WaitForSite',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'XenDesktop7',
  dscmeta_module_version: '2.10.0',
  docs: 'The DSC XD7WaitForSite resource type.
         Automatically generated from version 2.10.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_existingcontrollername: {
      type: 'String',
      desc: 'Citrix XenDesktop 7 site controller.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_retrycount: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Retry count before timing out.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'User account that has permission to connect to the site.',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_retryintervalsec: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'Interval between retries in seconds.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_sitename: {
      type: 'String',
      desc: 'Citrix XenDesktop 7 site name.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
